# QI IRIDA Utils

[![Linux](https://img.shields.io/travis/happykhan/qi-irida-utils.svg)](https://travis-ci.org/happykhan/qi-irida-utils)
[![Windows build status on
Appveyor](https://ci.appveyor.com/api/projects/status/github/happykhan/qi-irida-utils?branch=master&svg=true)](https://ci.appveyor.com/project/happykhan/qi-irida-utils/branch/master)
[![Documentation
Status](https://readthedocs.org/projects/qi-irida-utils/badge/?version=latest)](https://qi-irida-utils.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/v/qi-irida-utils.svg)](https://pypi.python.org/pypi/qi-irida-utils)
[![Docker build
status](https://img.shields.io/docker/pulls/happykhan/qi-irida-utils.svg)](https://hub.docker.com/r/happykhan/qi-irida-utils)

[![Coverage](https://img.shields.io/coveralls/happykhan/qi-irida-utils/master.svg)](https://coveralls.io/r/happykhan/qi-irida-utils/)
[![Coverage](https://img.shields.io/scrutinizer/g/happykhan/qi-irida-utils.svg)](https://scrutinizer-ci.com/g/happykhan/qi-irida-utils/?branch=master)
[![Updates](https://pyup.io/repos/github/happykhan/qi-irida-utils/shield.svg)](https://pyup.io/repos/github/happykhan/qi-irida-utils/)

Helper scripts for working with IRIDA

See the documentation for more details:
<https://qi-irida-utils.readthedocs.io>.

## Introduction

## Quick start

## Installation

## Usage

## Outputs

## License

QI IRIDA Utils is free software, licensed under GNU General Public
License v3

## Feedback/Issues

Please report any issues to the [issues
page](https://github.com/happykhan/qi-irida-utils/issues).

## Citation

QI IRIDA Utils is not formally published. Please cite
<https://github.com/happykhan/qi-irida-utils>

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the [QI
python template](https://github.com/happykhan/qi-python-package) project
template.
